All files / src/ast/reference variable-reference.ts

100% Statements 5/5
100% Branches 0/0
100% Functions 4/4
100% Lines 5/5

Press n or j to go to the next uncovered block, b, p or k for the previous block.

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27                  131x 131x         22x       137x       4x      
import type { ExpressionState } from '../../expression-state.js';
import { TypedValue } from '../../typed-value.js';
import { SpelNodeImpl } from '../spel-node.js';
import { NodeType } from '../../language/node-type.js';
 
export class VariableReference extends SpelNodeImpl {
  private readonly variableName: string;
 
  constructor(startPos: number, endPos: number, variableName: string) {
    super(NodeType.VARIABLE_REFERENCE, startPos, endPos);
    this.variableName = variableName;
  }
 
  /** Get the variable name (without # prefix) */
  public getVariableName(): string {
    return this.variableName;
  }
 
  public getValueInternal(state: ExpressionState): TypedValue {
    return state.lookupVariable(this.variableName);
  }
 
  public toStringAST(): string {
    return '#' + this.variableName;
  }
}