Press n or j to go to the next uncovered block, b, p or k for the previous block.
| 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 | 1x 1x 1x 1x 115x 115x 115x 115x 115x 115x 22x 22x 115x 112x 112x 115x 4x 4x 115x | import type { ExpressionState } from '../../expression-state.js';
import { TypedValue } from '../../typed-value.js';
import { SpelNodeImpl } from '../spel-node.js';
import { NodeType } from '../../language/node-type.js';
export class VariableReference extends SpelNodeImpl {
private readonly variableName: string;
constructor(startPos: number, endPos: number, variableName: string) {
super(NodeType.VARIABLE_REFERENCE, startPos, endPos);
this.variableName = variableName;
}
/** Get the variable name (without # prefix) */
public getVariableName(): string {
return this.variableName;
}
public getValueInternal(state: ExpressionState): TypedValue {
return state.lookupVariable(this.variableName);
}
public toStringAST(): string {
return '#' + this.variableName;
}
}
|